@@ -57,7 +57,8 @@ def _absolute_sub_directories(
 
 
 def get_ignored_files(
-    root_directory: str, exclude_directories: FrozenSet[str] = frozenset(),
+    root_directory: str,
+    exclude_directories: FrozenSet[str] = frozenset(),
 ) -> Iterable[str]:
     """
     Yield the absolute path of all ignored files, excluding those in any of the
@@ -144,7 +145,8 @@ def delete_empty_directories(
 
 
 def delete_ignored(
-    root_directory: str, exclude_directories: FrozenSet[str] = frozenset(),
+    root_directory: str,
+    exclude_directories: FrozenSet[str] = frozenset(),
 ) -> None:
     """
     Delete files which are ignored by Git.
@@ -161,7 +163,7 @@ def delete_ignored(
         os.remove(path)
 
 
-def main(
+def clean(
     root_directory: str = ".",
     exclude_directories: FrozenSet[str] = EXCLUDE_DIRECTORIES,
 ) -> None:
@@ -181,14 +183,14 @@ def main(
     )
 
 
-main.__doc__ = main.__doc__.format(  # type: ignore
+clean.__doc__ = clean.__doc__.format(  # type: ignore
     EXCLUDE_DIRECTORIES=EXCLUDE_DIRECTORIES
 )
 
 
-if __name__ == "__main__":
+def main() -> None:
     parser: argparse.ArgumentParser = argparse.ArgumentParser(
-        description='Parse command-line arguments for a "clean" operation'
+        prog="daves-dev-tool clean"
     )
     parser.add_argument(
         "--exclude",
@@ -209,7 +211,7 @@ if __name__ == "__main__":
         help="The root directory path for the project.",
     )
     arguments: argparse.Namespace = parser.parse_args()
-    main(
+    clean(
         root_directory=arguments.root,
         exclude_directories=(
             frozenset(os.path.split(arguments.exclude))
@@ -217,3 +219,7 @@ if __name__ == "__main__":
             else EXCLUDE_DIRECTORIES
         ),
     )
+
+
+if __name__ == "__main__":
+    main()
